# ewoksdask

[![Pipeline](https://github.com/ewoks-kit/ewoksdask/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/ewoks-kit/ewoksdask/actions/workflows/test.yml)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![License](https://img.shields.io/github/license/ewoks-kit/ewoksdask)](https://github.com/ewoks-kit/ewoksdask/blob/main/LICENSE.md)
[![Coverage](https://codecov.io/gh/ewoks-kit/ewoksdask/branch/main/graph/badge.svg)](https://codecov.io/gh/ewoks-kit/ewoksdask)
[![Docs](https://readthedocs.org/projects/ewoksdask/badge/?version=latest)](https://ewoksdask.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/ewoksdask)](https://pypi.org/project/ewoksdask/)

*ewoksdask* provides distributed task scheduling for [ewoks](https://ewoks.readthedocs.io/) workflows.

## Install

```bash
pip install ewoksdask[test]
```

## Test

```bash
pytest --pyargs ewoksdask.tests
```

## Documentation

https://ewoksdask.readthedocs.io/

